cheesecake

Package cheesecake |
[show private | hide private]
[frames | no frames]

## Package cheesecake

Submodules
`ast_pp` `cheesecake_index`: Cheesecake: How tasty is your code? `codeparser` `logger` `model`: Code borrowed from Michael Hudson's docextractor package with the author's permission. `pep8`: Check Python source code formatting, according to PEP 8: http://www.python.org/dev/peps/pep-0008/ `subprocess`: subprocess - Subprocesses with accessible I/O streams This module allows you to spawn processes, connect to their input/output/error pipes, and obtain their return codes. `util`: Utility functions for Cheesecake project.

Variable Summary
`str` | `__version__` = `'0.6.1'`

Variable Details

    ### __version__ Type: `str` Value:
        '0.6.1'

Generated by Epydoc 2.1 on Fri Feb 9 02:15:12 2007 | http://epydoc.sf.net